==> eam-wshub-proxyclient-11.7-4-sources.jar: net/datastream/schemas/mp_entities/store2storetransfer_001/PartLine.java <==

package net.datastream.schemas.mp_entities.store2storetransfer_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BINID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.LOTID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REPAIRABLE" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}REPAIRQUANTITY" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}FROMBIN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TOBIN"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}LOTID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PRICE"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ASSETID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SERIALNUMBER" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partid",
    "repairable",
    "transactionquantity",
    "repairquantity",
    "frombin",
    "tobin",
    "lotid",
    "price",
    "assetid",
    "serialnumber",
    "standardUserDefinedFields",
    "partconditiontemplateconditioncode"
})
@XmlRootElement(name = "PartLine")
public class PartLine {

    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "REPAIRABLE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String repairable;
    @XmlElement(name = "TRANSACTIONQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT transactionquantity;
    @XmlElement(name = "REPAIRQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY repairquantity;
    @XmlElement(name = "FROMBIN", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected BINID_Type frombin;
    @XmlElement(name = "TOBIN", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected BINID_Type tobin;
    @XmlElement(name = "LOTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected LOTID_Type lotid;
    @XmlElement(name = "PRICE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT price;
    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "SERIALNUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String serialnumber;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the repairable property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREPAIRABLE() {
        return repairable;
    }

    /**
     * Sets the value of the repairable property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREPAIRABLE(String value) {
        this.repairable = value;
    }

    /**
     * Gets the value of the transactionquantity property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTRANSACTIONQUANTITY() {
        return transactionquantity;
    }

    /**
     * Sets the value of the transactionquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTRANSACTIONQUANTITY(AMOUNT value) {
        this.transactionquantity = value;
    }

    /**
     * Gets the value of the repairquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREPAIRQUANTITY() {
        return repairquantity;
    }

    /**
     * Sets the value of the repairquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREPAIRQUANTITY(QUANTITY value) {
        this.repairquantity = value;
    }

    /**
     * Gets the value of the frombin property.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getFROMBIN() {
        return frombin;
    }

    /**
     * Sets the value of the frombin property.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setFROMBIN(BINID_Type value) {
        this.frombin = value;
    }

    /**
     * Gets the value of the tobin property.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getTOBIN() {
        return tobin;
    }

    /**
     * Sets the value of the tobin property.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setTOBIN(BINID_Type value) {
        this.tobin = value;
    }

    /**
     * Gets the value of the lotid property.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Sets the value of the lotid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

    /**
     * Gets the value of the price property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getPRICE() {
        return price;
    }

    /**
     * Sets the value of the price property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setPRICE(AMOUNT value) {
        this.price = value;
    }

    /**
     * Gets the value of the assetid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Sets the value of the assetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Gets the value of the serialnumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSERIALNUMBER() {
        return serialnumber;
    }

    /**
     * Sets the value of the serialnumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSERIALNUMBER(String value) {
        this.serialnumber = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the partconditiontemplateconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Sets the value of the partconditiontemplateconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

}

==> eam-wshub-proxyclient-12.1.0-21-sources.jar: net/datastream/schemas/mp_entities/store2storetransfer_001/PartLine.java <==

package net.datastream.schemas.mp_entities.store2storetransfer_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.BINID_Type;
import net.datastream.schemas.mp_fields.EQUIPMENTID_Type;
import net.datastream.schemas.mp_fields.LOTID_Type;
import net.datastream.schemas.mp_fields.PARTID_Type;
import net.datastream.schemas.mp_fields.StandardUserDefinedFields;
import org.openapplications.oagis_segments.AMOUNT;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PARTID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}REPAIRABLE" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONQUANTITY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}REPAIRQUANTITY" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}FROMBIN"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TOBIN"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}LOTID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PRICE"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}ASSETID" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SERIALNUMBER" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}StandardUserDefinedFields" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}PARTCONDITIONTEMPLATECONDITIONCODE" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "partid",
    "repairable",
    "transactionquantity",
    "repairquantity",
    "frombin",
    "tobin",
    "lotid",
    "price",
    "assetid",
    "serialnumber",
    "standardUserDefinedFields",
    "partconditiontemplateconditioncode"
})
@XmlRootElement(name = "PartLine")
public class PartLine {

    @XmlElement(name = "PARTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected PARTID_Type partid;
    @XmlElement(name = "REPAIRABLE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String repairable;
    @XmlElement(name = "TRANSACTIONQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected AMOUNT transactionquantity;
    @XmlElement(name = "REPAIRQUANTITY", namespace = "http://schemas.datastream.net/MP_fields")
    protected QUANTITY repairquantity;
    @XmlElement(name = "FROMBIN", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected BINID_Type frombin;
    @XmlElement(name = "TOBIN", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected BINID_Type tobin;
    @XmlElement(name = "LOTID", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected LOTID_Type lotid;
    @XmlElement(name = "PRICE", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected AMOUNT price;
    @XmlElement(name = "ASSETID", namespace = "http://schemas.datastream.net/MP_fields")
    protected EQUIPMENTID_Type assetid;
    @XmlElement(name = "SERIALNUMBER", namespace = "http://schemas.datastream.net/MP_fields")
    protected String serialnumber;
    @XmlElement(name = "StandardUserDefinedFields", namespace = "http://schemas.datastream.net/MP_fields")
    protected StandardUserDefinedFields standardUserDefinedFields;
    @XmlElement(name = "PARTCONDITIONTEMPLATECONDITIONCODE", namespace = "http://schemas.datastream.net/MP_fields")
    protected String partconditiontemplateconditioncode;

    /**
     * Gets the value of the partid property.
     * 
     * @return
     *     possible object is
     *     {@link PARTID_Type }
     *     
     */
    public PARTID_Type getPARTID() {
        return partid;
    }

    /**
     * Sets the value of the partid property.
     * 
     * @param value
     *     allowed object is
     *     {@link PARTID_Type }
     *     
     */
    public void setPARTID(PARTID_Type value) {
        this.partid = value;
    }

    /**
     * Gets the value of the repairable property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getREPAIRABLE() {
        return repairable;
    }

    /**
     * Sets the value of the repairable property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setREPAIRABLE(String value) {
        this.repairable = value;
    }

    /**
     * Gets the value of the transactionquantity property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getTRANSACTIONQUANTITY() {
        return transactionquantity;
    }

    /**
     * Sets the value of the transactionquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setTRANSACTIONQUANTITY(AMOUNT value) {
        this.transactionquantity = value;
    }

    /**
     * Gets the value of the repairquantity property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getREPAIRQUANTITY() {
        return repairquantity;
    }

    /**
     * Sets the value of the repairquantity property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setREPAIRQUANTITY(QUANTITY value) {
        this.repairquantity = value;
    }

    /**
     * Gets the value of the frombin property.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getFROMBIN() {
        return frombin;
    }

    /**
     * Sets the value of the frombin property.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setFROMBIN(BINID_Type value) {
        this.frombin = value;
    }

    /**
     * Gets the value of the tobin property.
     * 
     * @return
     *     possible object is
     *     {@link BINID_Type }
     *     
     */
    public BINID_Type getTOBIN() {
        return tobin;
    }

    /**
     * Sets the value of the tobin property.
     * 
     * @param value
     *     allowed object is
     *     {@link BINID_Type }
     *     
     */
    public void setTOBIN(BINID_Type value) {
        this.tobin = value;
    }

    /**
     * Gets the value of the lotid property.
     * 
     * @return
     *     possible object is
     *     {@link LOTID_Type }
     *     
     */
    public LOTID_Type getLOTID() {
        return lotid;
    }

    /**
     * Sets the value of the lotid property.
     * 
     * @param value
     *     allowed object is
     *     {@link LOTID_Type }
     *     
     */
    public void setLOTID(LOTID_Type value) {
        this.lotid = value;
    }

    /**
     * Gets the value of the price property.
     * 
     * @return
     *     possible object is
     *     {@link AMOUNT }
     *     
     */
    public AMOUNT getPRICE() {
        return price;
    }

    /**
     * Sets the value of the price property.
     * 
     * @param value
     *     allowed object is
     *     {@link AMOUNT }
     *     
     */
    public void setPRICE(AMOUNT value) {
        this.price = value;
    }

    /**
     * Gets the value of the assetid property.
     * 
     * @return
     *     possible object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public EQUIPMENTID_Type getASSETID() {
        return assetid;
    }

    /**
     * Sets the value of the assetid property.
     * 
     * @param value
     *     allowed object is
     *     {@link EQUIPMENTID_Type }
     *     
     */
    public void setASSETID(EQUIPMENTID_Type value) {
        this.assetid = value;
    }

    /**
     * Gets the value of the serialnumber property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getSERIALNUMBER() {
        return serialnumber;
    }

    /**
     * Sets the value of the serialnumber property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setSERIALNUMBER(String value) {
        this.serialnumber = value;
    }

    /**
     * Gets the value of the standardUserDefinedFields property.
     * 
     * @return
     *     possible object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public StandardUserDefinedFields getStandardUserDefinedFields() {
        return standardUserDefinedFields;
    }

    /**
     * Sets the value of the standardUserDefinedFields property.
     * 
     * @param value
     *     allowed object is
     *     {@link StandardUserDefinedFields }
     *     
     */
    public void setStandardUserDefinedFields(StandardUserDefinedFields value) {
        this.standardUserDefinedFields = value;
    }

    /**
     * Gets the value of the partconditiontemplateconditioncode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPARTCONDITIONTEMPLATECONDITIONCODE() {
        return partconditiontemplateconditioncode;
    }

    /**
     * Sets the value of the partconditiontemplateconditioncode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setPARTCONDITIONTEMPLATECONDITIONCODE(String value) {
        this.partconditiontemplateconditioncode = value;
    }

}
